@@ -55,16 +55,16 @@
       expect(actionHasId(actions, 'resizeClusterAction')).toBe(true);
     });
 
-    it('registers Update Cluster as an item action', function() {
-      var actions = registry.getResourceType('OS::Magnum::Cluster').itemActions;
-      expect(actionHasId(actions, 'updateClusterAction')).toBe(true);
-    });
-
     it('registers Delete Cluster as an item action', function() {
       var actions = registry.getResourceType('OS::Magnum::Cluster').itemActions;
       expect(actionHasId(actions, 'deleteClusterAction')).toBe(true);
     });
 
+    it('registers Get Cluster Config as an item action', function() {
+      var actions = registry.getResourceType('OS::Magnum::Cluster').itemActions;
+      expect(actionHasId(actions, 'getClusterConfigAction')).toBe(true);
+    });
+
     function actionHasId(list, value) {
       return list.filter(matchesId).length === 1;
 
